"use client";

import "./MapSearch.scss";
import Image from "next/image";
import search from "./icons/search.svg";
import { IDisplayMap } from "@/shared/types/map-type";

interface IMapSearchProps
  extends React.InputHTMLAttributes<HTMLInputElement> {
  options: IDisplayMap[];
  setMapSearch: (string: string) => void;
  setLatLng: ({ lat, lng }: { lat: number; lng: number }) => void;
}

const MapSearch: React.FC<IMapSearchProps> = ({
  name,
  placeholder,
  value,
  onChange,
  options,
  setMapSearch,
  setLatLng,
}: IMapSearchProps) => {
  const handleSubmit = (
    display_name: string,
    latLng: { lat: number; lng: number }
  ) => {
    setMapSearch(display_name);
    setLatLng(latLng);
  };
  return (
    <div className="map-search">
      <form
        onSubmit={(e) => {
          e.preventDefault();
          handleSubmit(options[0].display_name, {
            lat: +options[0].lat,
            lng: +options[0].lon,
          });
        }}
      >
        <div className="map-search__input">
          <Image src={search} alt="Search Icon" />
          <input
            onChange={onChange}
            value={value}
            placeholder={placeholder}
            name={name}
            type="text"
          />
        </div>
        <button type="submit">Поиск</button>
      </form>

      {options.length !== 0 ? (
        <div className="map-search__recs">
          <ul>
            {options.map((opt) => (
              <li key={opt.place_id}>
                <button
                  onClick={() => {
                    setMapSearch(opt.display_name);
                    setLatLng({
                      lat: +opt.lat,
                      lng: +opt.lon,
                    });
                  }}
                >
                  {opt.display_name}
                </button>
              </li>
            ))}
          </ul>
        </div>
      ) : null}
    </div>
  );
};

export default MapSearch;
